      subroutine potini 
c
      implicit none
c
      include "Bounds.p"
      include "Constants.p"
      include "System.h"
      include "Lennard_Jones.p"
      include "Lennard_Jones.h"
      include "Phantom.h"
      include "Increm.h"
      include "Intend.h"
      include "Current.h"
c
      integer      i,j, k, nintr, nends, npen
c
      real*8       U1, U1p, U1pp, Rtruncsq
      real*8       psin, del
      real*8       sig6, sig12
      real*8       r2, r, t1,t2, t3, t4, t5
      real*8       coeff(0:5), c1, c2, c3
      real*8       Ispl, ILJ, truncsc(maxtypsq)
      real*8       sigsq, ratio,ratio6, ratio3, small,big
c
c     _______________________________________________________________
c
c     Do loop over different epsilon parameters
c
        do i=1,ntypsq

        anb       = 4.d0 * eps(i) * sigreal(i)**12
        cnb       = 4.d0 * eps(i) * sigreal(i)**6
        Rtrunc    = 1.45d0 * sigreal(i)
        rmaxnb    = 2.33d0 * sigreal(i)
        r2nb(i)   = rmaxnb * rmaxnb
        r2nbp     = (rmaxnb + shell(i))**2
        Rtruncsq  = Rtrunc * Rtrunc
        del       = (rmaxnb - Rtrunc) / sigreal(i)
        U1        = (anb/Rtrunc**12)-(cnb/Rtrunc**6)
        U1p       = -12.d0 * (anb/Rtrunc**13)+ 6.d0*
     :            (cnb/Rtrunc**7)
        U1pp      = 156.d0 * (anb/Rtrunc**14) - 42.d0*
     :            (cnb/Rtrunc**8)
c
c     coefficients for the quintic spline approximation to the 
c     Lennard-Jones potential:
c
        c1 = U1
        c2 = del * U1p * sigreal(i)
        c3 = 0.5d0 * (del*del) * U1pp * (sigreal(i)*sigreal(i))
c
        coeff(0) = c1
        coeff(1) = c2
        coeff(2) = c3
        coeff(3) = -(10.d0 * c1) - (6.d0 * c2) - (3.d0 * c3)
        coeff(4) =  (15.d0 * c1) + (8.d0 * c2) + (3.d0 * c3)
        coeff(5) = -(6.d0  * c1) - (3.d0 * c2) -         c3
c
c     Integral of the Lennard-Jones from Rtrunc to rmaxnb:
c
        sig6  = sigreal(i) ** 6
        sig12 = sigreal(i) ** 12
c
        ILJ = (- (sig12/9.d0) * (1.d0/rmaxnb**9 - 1.d0/Rtrunc**9)
     :       + (sig6 /3.d0) * (1.d0/rmaxnb**3 - 1.d0/Rtrunc**3)) 
     :       * 4.d0 * eps(i)
c
c     Integral of the quintic spline from Rtrunc to rmaxnb:
c
        Ispl =  ( coeff(0)   + coeff(1)/2 + coeff(2)/3 
     :        + coeff(3)/4 + coeff(4)/5 + coeff(5)/6 ) *
     :            (rmaxnb - Rtrunc)     * Rtrunc**2 +
     :        ( coeff(0)/2 + coeff(1)/3 + coeff(2)/4
     :        + coeff(3)/5 + coeff(4)/6 + coeff(5)/7 ) *
     :            (rmaxnb - Rtrunc)**2  * Rtrunc * 2.d0 +
     :        ( coeff(0)/3 + coeff(1)/4 + coeff(2)/5
     :        + coeff(3)/6 + coeff(4)/7 + coeff(5)/8 ) *
     :            (rmaxnb - Rtrunc)**3
c
c     The truncation potential (before multiplication by rho/2)
c     between Rtrunc and rmaxnb; also beyond rmaxnb;
c     compute the potential dividing the region {sigma^2/ 8, rmaxnb*1.2}
c     into ngridnb intervals; piece together the potential in "elj"
c
        truncsc(i)  = 4.d0 * pi * (ILJ - Ispl)
        truncsc(i)  = truncsc(i) - 4.d0 * pi * (cnb/3.d0) 
     :              / (rmaxnb**3)
        sigsq       = sigreal(i) * sigreal(i)
        small       = sigsq / 8.d0
	  big         = 4.0d0/small**6
        interval(i) = r2nbp / ngridnb
c
      do k = 1, ngridnb
         r2 = interval(i) * dfloat(k)
         r  = dsqrt(r2)
c
         if      (r2.lt.small) then
            elj(k,i) = eps(i) * sigsq * big
         else if (r2.lt.Rtruncsq) then
            ratio  = sigsq / r2
	      ratio3 = ratio*ratio*ratio
	      ratio6=ratio3*ratio3
            elj(k,i) = 4.d0 * eps(i) * (ratio6 - ratio3)
         else if (r2.lt.r2nb(i)) then
            psin = (r - Rtrunc) / (rmaxnb - Rtrunc)
            elj(k,i) = coeff(0) + psin * (
     :                 coeff(1) + psin * (
     :                 coeff(2) + psin * (
     :                 coeff(3) + psin * (
     :                 coeff(4) + psin * (
     :                 coeff(5))))))

c            write(*,*)"elj",k,r2,elj(k,i),"spline"
         else
            elj(k,i) = 0.d0
c            write(*,*)"elj",k,r,elj(k,i),"0"
         end if
      end do

      enddo
c	
c	October 2005: num(1:ntyp) has been read from input file;
c	and now lets detemine truncscph...  
c
      do i = 1,ntyp
        truncscph(i) = 0.0d0
        do j = 1,ntyp
          truncscph(i) = truncscph(i)+num(j)*truncsc(pairtype(i,j))
        enddo
      enddo
c
c
c
      return
      end
